<!DOCTYPE html>
<html lang="pt-BR">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- The above 3 meta tags *must* come first in the head; any other head content must come *after* these tags -->
    <meta name="description" content="Compartilhamento do equipamento SAT via RESTful API">
    <meta name="author" content="Base4 Sistemas Ltda">
    <link rel="icon" type="image/png" href="{{ url_for('static', filename='favicon.png') }}">
    <title>{{ produto.nome }} {{ produto.versao }}</title>
    <link rel="stylesheet" href="{{ url_for('static', filename='bootstrap-3.3.5/css/bootstrap.min.css') }}" >
    <link rel="stylesheet" href="{{ url_for('static', filename='custom.css') }}" >
    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
      <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->
    {% block inside_head %}{% endblock %}
  </head>
  <body>
    <div class="container">
      {% block container_content %}{% endblock %}
    </div> <!-- container -->
    <!-- Bootstrap core JavaScript -->
    <script src="{{ url_for('static', filename='jquery-1.11.3/jquery.min.js') }}"></script>
    <script src="{{ url_for('static', filename='bootstrap-3.3.5/js/bootstrap.min.js') }}"></script>
    <!-- IE10 viewport hack for Surface/desktop Windows 8 bug -->
    <script src="{{ url_for('static', filename='bootstrap-3.3.5/js/ie10-viewport-bug-workaround.js') }}"></script>
    {% block custom_script %}{% endblock %}
  </body>
</html>
