{% extends "base-navbar.html" %}
{% block content %}
      <div class="jumbotron">
        <h1><strong>{{ produto.nome }}</strong></h1>
        <p>Compartilhamento do equipamento SAT.<br/> Conecte mais de um ponto-de-venda a um único equipamento SAT</p>
        <p>
          <a class="btn btn-lg btn-primary" href="https://github.com/base4sistemas/sathub" role="button">Saiba mais &raquo;</a>
        </p>
      </div>
{% endblock %}
